pub enum Operation {
Call {
canister: Principal,
method: String,
},
ReadState {
paths: Vec<Vec<String>>,
canister: Principal,
},
ReadSubnetState {
paths: Vec<Vec<String>>,
subnet: Principal,
},
}Expand description
An operation that can result in a reject.
Variants
Call
A call to a canister method.
Fields
ReadState
A read of the state tree, in the context of a canister. This will not be returned for request polling.
Fields
ReadSubnetState
A read of the state tree, in the context of a subnet.