Enum ic_agent::agent::PollResult [−][src]
Classification of the result of a request_status_raw (poll) call.
Variants
The request has been submitted, but we do not know yet if it has been accepted or not.
The request has been received and may be processing.
The request completed and returned some data.