Enum ic_agent::agent::RequestStatusResponse [−][src]
pub enum RequestStatusResponse {
Unknown,
Received,
Processing,
Replied {
reply: Replied,
},
Rejected {
reject_code: u64,
reject_message: String,
},
Done,
}Expand description
The response of /api/v2/canister/<effective_canister_id>/read_state with “request_status” request type.
Variants
Show fields
Fields of Replied
reply: RepliedTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more