Enum ic_agent::agent::status::Value [−][src]
pub enum Value {
Null,
String(String),
Integer(i64),
Bool(bool),
Bytes(Vec<u8>),
Vec(Vec<Value>),
Map(BTreeMap<String, Box<Value>>),
}Expand description
Value returned by the status endpoint of a replica. This is a loose mapping to CBOR values.
Because the agent should not return serde_cbor::Value directly across API boundaries,
we reimplement it as Value here.
Variants
Tuple Fields of String
0: StringTuple Fields of Integer
0: i64Tuple Fields of Bool
0: boolTrait Implementations
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more