Struct ic_agent::agent::AgentBuilder [−][src]
pub struct AgentBuilder { /* fields omitted */ }Implementations
Create an instance of Agent with the information from this builder.
👎 Deprecated since 0.3.0: Prefer using with_transport().
👎 Deprecated since 0.3.0:
Prefer using with_transport().
Set the URL of the Agent.
pub fn with_transport<F: 'static + ReplicaV2Transport + Send + Sync>(
self,
transport: F
) -> Self
pub fn with_transport<F: 'static + ReplicaV2Transport + Send + Sync>(
self,
transport: F
) -> SelfSet a Replica transport to talk to serve as the replica interface.
Add a NonceFactory to this Agent. By default, no nonce is produced.
Add an identity provider for signing messages. This is required.
Same as [with_identity], but provides a boxed implementation instead of a direct type.
Provides a default ingress expiry. This is the delta that will be applied at the time an update or query is made. The default expiry cannot be a fixed system time.