Types and traits dealing with identity across the Internet Computer.
Structs
- Anonymous
Identity - The anonymous identity.
- Basic
Identity - A cryptographic identity which signs using an Ed25519 key pair.
- Delegated
Identity - An identity that has been delegated the authority to authenticate as a different principal.
- Delegation
- A delegation from one key to another.
- Info
Aware Identity - An identity wrapper that attaches canister-certified sender information to every request.
- Prime256v1
Identity - A cryptographic identity based on the Prime256v1 elliptic curve.
- Secp256k1
Identity - A cryptographic identity based on the Secp256k1 elliptic curve.
- Sender
Info - Canister-certified sender information attached to a request envelope.
- Signature
- A cryptographic signature, signed by an Identity.
- Signed
Delegation - A
Delegationthat has been signed by anIdentity.
Enums
- Delegation
Error - An error occurred constructing a
DelegatedIdentity. - Delegation
Permissions - The kinds of requests a
Delegationpermits. - PemError
pem - An error happened while reading a PEM file.
Traits
- Identity
- An
IdentityproducesSignaturesfor requests or delegations. It knows or represents thePrincipalof the sender.